from no_llm.models.llama.llama_3_1_405b import Llama31405BConfiguration
from no_llm.models.llama.llama_3_3_70b import Llama3370BConfiguration

__all__ = [
    "Llama31405BConfiguration",
    "Llama3370BConfiguration",
]
